---
name: Feature request
about: Suggest an idea for this project
title: "[FEATURE]"
labels: enhancement
assignees: ''

---

### Is your feature request related to a problem

Is your feature request related to a problem?

Add a clear and concise description of what the problem is. Ex. I want to be able to [...] but I can't because [...]

### The solution you would like

Add a clear and concise description of what you want to happen.

### Describe alternatives you've considered

Add a clear and concise description of any alternative solutions or features you've considered.

### Additional context

Add any other context or screenshots about the feature request here.
